@@ -13,7 +13,11 @@ def signed_request(method, url, data=None, params=None, headers=None):
     logging.info(f"signalsdk::accesskey: {creds.access_key}, secretkey: {creds.secret_key}")
     request = AWSRequest(method=method, url=url, data=data, params=params, headers=headers)
     SigV4Auth(creds, "execute-api", 'us-east-1').add_auth(request)
-    response = requests.request(method=method, url=url, headers=dict(request.headers), data=data)
+    response = requests.request(method=method,
+                                url=url,
+                                headers=dict(request.headers),
+                                data=data,
+                                timeout=300)
     if response.status_code == 200:
         return response.json()
     raise SignalAppSignedReqError
